@@ -9,21 +9,19 @@ import cairo
 def ceil(f):
     return int(math.ceil(f))
 
+
 line = 10
 curve = 60
 dotSmall = 14
 dotLarge = 24
-lineprc = 1 / 7.
+lineprc = 1 / 7.0
 
 hpadding = 5
 vpadding = 3
 
 
 class SpotGraph(Gtk.EventBox):
-
-    __gsignals__ = {
-        'spotClicked': (GObject.SignalFlags.RUN_FIRST, None, (str, ))
-    }
+    __gsignals__ = {"spotClicked": (GObject.SignalFlags.RUN_FIRST, None, (str,))}
 
     def __init__(self):
         GObject.GObject.__init__(self)
@@ -32,20 +30,24 @@ class SpotGraph(Gtk.EventBox):
         # rgb 85,152,215 = Rated
         # rgb 115,210,22 = Unrated
         # rgb 189,47,26 = Computer
-        self.typeColors = [[[85, 152, 215], [59, 106, 151]],
-                           [[115, 210, 22], [78, 154, 6]],
-                           [[85, 152, 215], [189, 47, 26]],
-                           [[115, 210, 22], [189, 47, 26]]]
+        self.typeColors = [
+            [[85, 152, 215], [59, 106, 151]],
+            [[115, 210, 22], [78, 154, 6]],
+            [[85, 152, 215], [189, 47, 26]],
+            [[115, 210, 22], [189, 47, 26]],
+        ]
         for type in self.typeColors:
             for color in type:
-                color[0] = color[0] / 255.
-                color[1] = color[1] / 255.
-                color[2] = color[2] / 255.
+                color[0] = color[0] / 255.0
+                color[1] = color[1] / 255.0
+                color[2] = color[2] / 255.0
 
-        self.add_events(Gdk.EventMask.LEAVE_NOTIFY_MASK |
-                        Gdk.EventMask.POINTER_MOTION_MASK |
-                        Gdk.EventMask.BUTTON_PRESS_MASK |
-                        Gdk.EventMask.BUTTON_RELEASE_MASK)
+        self.add_events(
+            Gdk.EventMask.LEAVE_NOTIFY_MASK
+            | Gdk.EventMask.POINTER_MOTION_MASK
+            | Gdk.EventMask.BUTTON_PRESS_MASK
+            | Gdk.EventMask.BUTTON_RELEASE_MASK
+        )
         self.state = 0
         self.connect("button_press_event", self.button_press)
         self.connect("button_release_event", self.button_release)
@@ -101,24 +103,30 @@ class SpotGraph(Gtk.EventBox):
         context.set_line_width(line)
         context.set_line_cap(cairo.LINE_CAP_ROUND)
         # state = self.state == Gtk.StateType.NORMAL and Gtk.StateType.PRELIGHT or self.state
-        context.set_source_rgba(dark_prelight.red, dark_prelight.green,
-                                dark_prelight.blue, dark_prelight.alpha)
+        context.set_source_rgba(
+            dark_prelight.red,
+            dark_prelight.green,
+            dark_prelight.blue,
+            dark_prelight.alpha,
+        )
         context.stroke()
 
         # ------------------------------------------------ Paint horizontal marks
         for x_loc, title in self.xmarks:
-            context.set_source_rgba(fg_prelight.red, fg_prelight.green,
-                                    fg_prelight.blue, fg_prelight.alpha)
+            context.set_source_rgba(
+                fg_prelight.red, fg_prelight.green, fg_prelight.blue, fg_prelight.alpha
+            )
             context.set_font_size(12)
             x_loc, y_loc = self.prcToPix(x_loc, 1)
-            context.move_to(x_loc + line / 2., y_loc - line / 2.)
+            context.move_to(x_loc + line / 2.0, y_loc - line / 2.0)
             context.rotate(-math.pi / 2)
             context.show_text(title)
             context.rotate(math.pi / 2)
 
-            context.set_source_rgba(bg_prelight.red, bg_prelight.green,
-                                    bg_prelight.blue, bg_prelight.alpha)
-            context.move_to(x_loc - line / 2., y_loc)
+            context.set_source_rgba(
+                bg_prelight.red, bg_prelight.green, bg_prelight.blue, bg_prelight.alpha
+            )
+            context.move_to(x_loc - line / 2.0, y_loc)
             context.rel_curve_to(6, 0, 6, line, 6, line)
             context.rel_curve_to(0, -line, 6, -line, 6, -line)
             context.close_path()
@@ -126,16 +134,18 @@ class SpotGraph(Gtk.EventBox):
 
         # -------------------------------------------------- Paint vertical marks
         for y_loc, title in self.ymarks:
-            context.set_source_rgba(fg_prelight.red, fg_prelight.green,
-                                    fg_prelight.blue, fg_prelight.alpha)
+            context.set_source_rgba(
+                fg_prelight.red, fg_prelight.green, fg_prelight.blue, fg_prelight.alpha
+            )
             context.set_font_size(12)
             x_loc, y_loc = self.prcToPix(0, y_loc)
-            context.move_to(x_loc + line / 2., y_loc + line / 2.)
+            context.move_to(x_loc + line / 2.0, y_loc + line / 2.0)
             context.show_text(title)
 
-            context.set_source_rgba(bg_prelight.red, bg_prelight.green,
-                                    bg_prelight.blue, bg_prelight.alpha)
-            context.move_to(x_loc, y_loc - line / 2.)
+            context.set_source_rgba(
+                bg_prelight.red, bg_prelight.green, bg_prelight.blue, bg_prelight.alpha
+            )
+            context.move_to(x_loc, y_loc - line / 2.0)
             context.rel_curve_to(0, 6, -line, 6, -line, 6)
             context.rel_curve_to(line, 0, line, 6, line, 6)
             context.close_path()
@@ -149,7 +159,7 @@ class SpotGraph(Gtk.EventBox):
                 continue
 
             x_loc, y_loc = self.prcToPix(x_loc, y_loc)
-            context.arc(x_loc, y_loc, dotSmall / (1 + lineprc) / 2., 0, 2 * math.pi)
+            context.arc(x_loc, y_loc, dotSmall / (1 + lineprc) / 2.0, 0, 2 * math.pi)
             context.fill_preserve()
             context.set_source_rgb(*self.typeColors[col_type][1])
             context.stroke()
@@ -163,7 +173,7 @@ class SpotGraph(Gtk.EventBox):
                 context.set_source_rgb(*self.typeColors[col_type][0])
             else:
                 context.set_source_rgb(*self.typeColors[col_type][1])
-            context.arc(x_loc, y_loc, dotLarge / (1 + lineprc) / 2., 0, 2 * math.pi)
+            context.arc(x_loc, y_loc, dotLarge / (1 + lineprc) / 2.0, 0, 2 * math.pi)
             context.fill_preserve()
             context.set_source_rgb(*self.typeColors[col_type][1])
             context.stroke()
@@ -174,16 +184,27 @@ class SpotGraph(Gtk.EventBox):
             style_ctxt.save()
             style_ctxt.add_class(Gtk.STYLE_CLASS_NOTEBOOK)
             Gtk.render_background(
-                style_ctxt, context, int(x_loc - hpadding), int(y_loc - vpadding),
-                ceil(width + hpadding * 2), ceil(height + vpadding * 2))
-            Gtk.render_frame(style_ctxt, context, int(x_loc - hpadding), int(y_loc - vpadding),
-                             ceil(width + hpadding * 2),
-                             ceil(height + vpadding * 2))
+                style_ctxt,
+                context,
+                int(x_loc - hpadding),
+                int(y_loc - vpadding),
+                ceil(width + hpadding * 2),
+                ceil(height + vpadding * 2),
+            )
+            Gtk.render_frame(
+                style_ctxt,
+                context,
+                int(x_loc - hpadding),
+                int(y_loc - vpadding),
+                ceil(width + hpadding * 2),
+                ceil(height + vpadding * 2),
+            )
             style_ctxt.restore()
 
             context.move_to(x_loc, y_loc)
-            context.set_source_rgba(fg_prelight.red, fg_prelight.green,
-                                    fg_prelight.blue, fg_prelight.alpha)
+            context.set_source_rgba(
+                fg_prelight.red, fg_prelight.green, fg_prelight.blue, fg_prelight.alpha
+            )
             PangoCairo.show_layout(context, self.create_pango_layout(text))
 
     ############################################################################
@@ -204,7 +225,8 @@ class SpotGraph(Gtk.EventBox):
         if self.hovered:
             self.redraw_canvas(self.getBounds(self.hovered))
             if event.button == 1 and self.pointIsOnSpot(
-                    event.x + alloc.x, event.y + alloc.y, self.hovered):
+                event.x + alloc.x, event.y + alloc.y, self.hovered
+            ):
                 self.emit("spotClicked", self.hovered[3])
 
     def motion_notify(self, widget, event):
@@ -232,7 +254,7 @@ class SpotGraph(Gtk.EventBox):
     ############################################################################
 
     def addSpot(self, name, text, x0, y0, colour_type=0):
-        """ x and y are in % from 0 to 1 """
+        """x and y are in % from 0 to 1"""
         assert colour_type in range(len(self.typeColors))
 
         if self.get_allocation().width <= 1:
@@ -242,8 +264,11 @@ class SpotGraph(Gtk.EventBox):
         x_loc1, y_loc1 = self.getNearestFreeNeighbourHexigon(x0, 1 - y0)
         spot = (x_loc1, y_loc1, colour_type, name, text)
         self.spots[name] = spot
-        if not self.hovered and self.cords and \
-                self.pointIsOnSpot(self.cords[0], self.cords[1], spot):
+        if (
+            not self.hovered
+            and self.cords
+            and self.pointIsOnSpot(self.cords[0], self.cords[1], spot)
+        ):
             self.hovered = spot
         self.redraw_canvas(self.getBounds(spot))
 
@@ -277,21 +302,26 @@ class SpotGraph(Gtk.EventBox):
 
         alloc = self.get_allocation()
         width = alloc.width
-#        height = alloc.height
+        #        height = alloc.height
 
         extends = self.create_pango_layout(text).get_extents()
         scale = float(Pango.SCALE)
-        x_bearing, y_bearing, twidth, theight = [extends[1].x / scale,
-                                                 extends[1].y / scale,
-                                                 extends[1].width / scale,
-                                                 extends[1].height / scale]
-        tx_loc = x_loc - x_bearing + dotLarge / 2.
-        ty_loc = y_loc - y_bearing - theight - dotLarge / 2.
+        x_bearing, y_bearing, twidth, theight = [
+            extends[1].x / scale,
+            extends[1].y / scale,
+            extends[1].width / scale,
+            extends[1].height / scale,
+        ]
+        tx_loc = x_loc - x_bearing + dotLarge / 2.0
+        ty_loc = y_loc - y_bearing - theight - dotLarge / 2.0
 
-        if tx_loc + twidth > width and x_loc - x_bearing - twidth - dotLarge / 2. > alloc.x:
-            tx_loc = x_loc - x_bearing - twidth - dotLarge / 2.
+        if (
+            tx_loc + twidth > width
+            and x_loc - x_bearing - twidth - dotLarge / 2.0 > alloc.x
+        ):
+            tx_loc = x_loc - x_bearing - twidth - dotLarge / 2.0
         if ty_loc < alloc.y:
-            ty_loc = y_loc - y_bearing + dotLarge / 2.
+            ty_loc = y_loc - y_bearing + dotLarge / 2.0
 
         return (tx_loc, ty_loc, twidth, theight)
 
@@ -303,8 +333,13 @@ class SpotGraph(Gtk.EventBox):
         return (x_loc1, y_loc1, x_loc2 - x_loc1, y_loc2 - y_loc1)
 
     def getBounds(self, spot):
-
-        x_loc, y_loc, = spot[0], spot[1]
+        (
+            x_loc,
+            y_loc,
+        ) = (
+            spot[0],
+            spot[1],
+        )
         x_loc, y_loc = self.prcToPix(x_loc, y_loc)
 
         if spot == self.hovered:
@@ -312,27 +347,33 @@ class SpotGraph(Gtk.EventBox):
         else:
             size = dotSmall
 
-        bounds = (x_loc - size / 2. - 1, y_loc - size / 2. - 1, size + 2, size + 2)
+        bounds = (x_loc - size / 2.0 - 1, y_loc - size / 2.0 - 1, size + 2, size + 2)
 
         if spot == self.hovered:
             x_loc, y_loc, width, height = self.getTextBounds(spot)
-            tbounds = (x_loc - hpadding, y_loc - vpadding, width + hpadding * 2 + 1,
-                       height + vpadding * 2 + 1)
+            tbounds = (
+                x_loc - hpadding,
+                y_loc - vpadding,
+                width + hpadding * 2 + 1,
+                height + vpadding * 2 + 1,
+            )
             return self.join(bounds, tbounds)
 
         return bounds
 
     def getNearestFreeNeighbourHexigon(self, xorg, yorg):
-        """ This method performs an hexigon search for an empty place to put a
-            new dot. """
+        """This method performs an hexigon search for an empty place to put a
+        new dot."""
 
         x_loc, y_loc = self.prcToPix(xorg, yorg)
         # Start by testing current spot
         if self.isEmpty(x_loc, y_loc):
             return xorg, yorg
 
-        directions = [(math.cos((i + 2) * math.pi / 3),
-                       math.sin((i + 2) * math.pi / 3)) for i in range(6)]
+        directions = [
+            (math.cos((i + 2) * math.pi / 3), math.sin((i + 2) * math.pi / 3))
+            for i in range(6)
+        ]
 
         level = 1
         while True:
@@ -346,9 +387,9 @@ class SpotGraph(Gtk.EventBox):
             level += 1
 
     def getNearestFreeNeighbourArchi(self, xorg, yorg):
-        """ This method performs an archimedes-spircal search for an empty
-            place to put a new dot.
-            http://en.wikipedia.org/wiki/Archimedean_spiral """
+        """This method performs an archimedes-spircal search for an empty
+        place to put a new dot.
+        http://en.wikipedia.org/wiki/Archimedean_spiral"""
 
         xorg, yorg = self.prcToPix(xorg, yorg)
         # Start by testing current spot
@@ -360,9 +401,11 @@ class SpotGraph(Gtk.EventBox):
             # This is an approx to the equation
             # cos((radius-s)/(2pi)) = (radius^2+s^2-1)/(2*radius*s)
             # which gives the next point on the spiral 1 away.
-            radius = (4 * math.pi**3 * radius + radius**2 +
-                      math.sqrt(16 * math.pi**6 + 8 * math.pi**3 * radius + radius**4)) / \
-                (4 * math.pi**3 + 2 * radius)
+            radius = (
+                4 * math.pi**3 * radius
+                + radius**2
+                + math.sqrt(16 * math.pi**6 + 8 * math.pi**3 * radius + radius**4)
+            ) / (4 * math.pi**3 + 2 * radius)
 
             x_loc = radius * math.cos(radius) / (4 * math.pi) * dotSmall + xorg
             y_loc = radius * math.sin(radius) / (4 * math.pi) * dotSmall + yorg
@@ -370,8 +413,8 @@ class SpotGraph(Gtk.EventBox):
                 return self.pixToPrc(x_loc, y_loc)
 
     def getNearestFreeNeighbourSquare(self, xorg, yorg):
-        """ This method performs a spircal search for an empty square to put a
-            new dot. """
+        """This method performs a spircal search for an empty square to put a
+        new dot."""
 
         up = 2
         right = 1
@@ -385,7 +428,6 @@ class SpotGraph(Gtk.EventBox):
             return self.pixToPrc(x_loc, y_loc)
 
         while True:
-
             for i in range(right):
                 x_loc += dotSmall
                 if self.isEmpty(x_loc, y_loc):
@@ -413,9 +455,9 @@ class SpotGraph(Gtk.EventBox):
             up += 2
 
     def isEmpty(self, x0, y0):
-        """ Returns true if a spot placed on (x, y) is inside the graph and not
-            intersecting with other spots.
-            x and y should be in pixels, not percent """
+        """Returns true if a spot placed on (x, y) is inside the graph and not
+        intersecting with other spots.
+        x and y should be in pixels, not percent"""
 
         # Make sure spiral search don't put dots outside the graph
         x_loc, y_loc = self.prcToPix(0, 0)
@@ -427,15 +469,15 @@ class SpotGraph(Gtk.EventBox):
         # Tests if the spot intersects any other spots
         for x_loc1, y_loc1, type, name, text in self.spots.values():
             x_loc1, y_loc1 = self.prcToPix(x_loc1, y_loc1)
-            if (x_loc1 - x0)**2 + (y_loc1 - y0)**2 < dotSmall**2 - 0.1:
+            if (x_loc1 - x0) ** 2 + (y_loc1 - y0) ** 2 < dotSmall**2 - 0.1:
                 return False
 
         return True
 
     def pointIsOnSpot(self, x0, y0, spot):
-        """ Returns true if (x, y) is inside the spot 'spot'. The size of the
-            spot is determined based on its hoverness.
-            x and y should be in pixels, not percent """
+        """Returns true if (x, y) is inside the spot 'spot'. The size of the
+        spot is determined based on its hoverness.
+        x and y should be in pixels, not percent"""
 
         if spot == self.hovered:
             size = dotLarge
@@ -444,13 +486,13 @@ class SpotGraph(Gtk.EventBox):
 
         x_loc1, y_loc1, type, name, text = spot
         x_loc1, y_loc1 = self.prcToPix(x_loc1, y_loc1)
-        if (x_loc1 - x0)**2 + (y_loc1 - y0)**2 <= (size / 2.)**2:
+        if (x_loc1 - x0) ** 2 + (y_loc1 - y0) ** 2 <= (size / 2.0) ** 2:
             return True
         return False
 
     def getSpotAtPoint(self, x, y):
-        """ Returns the spot embrace (x, y) if any. Otherwise it returns None.
-            x and y should be in pixels, not percent """
+        """Returns the spot embrace (x, y) if any. Otherwise it returns None.
+        x and y should be in pixels, not percent"""
 
         if self.hovered and self.pointIsOnSpot(x, y, self.hovered):
             return self.hovered
@@ -464,16 +506,19 @@ class SpotGraph(Gtk.EventBox):
         return None
 
     def prcToPix(self, x, y):
-        """ Translates from 0-1 cords to real world cords """
+        """Translates from 0-1 cords to real world cords"""
         alloc = self.get_allocation()
-        return x * (alloc.width - line * 1.5 - dotLarge * 0.5) + line * 1.5 + alloc.x, \
-            y * (alloc.height - line * 1.5 - dotLarge * 0.5) + dotLarge * 0.5 + alloc.y
+        return (
+            x * (alloc.width - line * 1.5 - dotLarge * 0.5) + line * 1.5 + alloc.x,
+            y * (alloc.height - line * 1.5 - dotLarge * 0.5) + dotLarge * 0.5 + alloc.y,
+        )
 
     def pixToPrc(self, x, y):
-        """ Translates from real world cords to 0-1 cords """
+        """Translates from real world cords to 0-1 cords"""
         alloc = self.get_allocation()
-        return (x - line * 1.5 - alloc.x) / (alloc.width - line * 1.5 - dotLarge * 0.5), \
-               (y - dotLarge * 0.5 - alloc.y) / (alloc.height - line * 1.5 - dotLarge * 0.5)
+        return (x - line * 1.5 - alloc.x) / (
+            alloc.width - line * 1.5 - dotLarge * 0.5
+        ), (y - dotLarge * 0.5 - alloc.y) / (alloc.height - line * 1.5 - dotLarge * 0.5)
 
 
 if __name__ == "__main__":
@@ -490,8 +535,9 @@ if __name__ == "__main__":
 
     provider = Gtk.CssProvider.new()
     provider.load_from_data(data)
-    style_ctx.add_provider_for_screen(Gdk.Screen.get_default(), provider,
-                                      Gtk.STYLE_PROVIDER_PRIORITY_APPLICATION)
+    style_ctx.add_provider_for_screen(
+        Gdk.Screen.get_default(), provider, Gtk.STYLE_PROVIDER_PRIORITY_APPLICATION
+    )
 
     note_book = Gtk.Notebook()
     window.add(note_book)
@@ -499,8 +545,8 @@ if __name__ == "__main__":
     note_book.append_page(v_box, None)
 
     spot_graph = SpotGraph()
-    spot_graph.addXMark(.5, "Center")
-    spot_graph.addYMark(.5, "Center")
+    spot_graph.addXMark(0.5, "Center")
+    spot_graph.addYMark(0.5, "Center")
     v_box.pack_start(spot_graph, True, True, 0)
 
     button = Gtk.Button("New Spot")
